# Generated by Django 3.1.13 on 2021-11-19 18:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('security_backends_sql', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='celerytaskinvocationlog',
            options={'ordering': ('-start',), 'verbose_name': 'celery task', 'verbose_name_plural': 'celery tasks'},
        ),
        migrations.AlterModelOptions(
            name='celerytaskrunlog',
            options={'ordering': ('-start',), 'verbose_name': 'celery task run', 'verbose_name_plural': 'celery tasks run'},
        ),
        migrations.AlterModelOptions(
            name='commandlog',
            options={'ordering': ('-start',), 'verbose_name': 'command log', 'verbose_name_plural': 'command logs'},
        ),
        migrations.AlterModelOptions(
            name='inputrequestlog',
            options={'ordering': ('-start',), 'verbose_name': 'input logged request', 'verbose_name_plural': 'input logged requests'},
        ),
        migrations.AlterModelOptions(
            name='outputrequestlog',
            options={'ordering': ('-start',), 'verbose_name': 'output logged request', 'verbose_name_plural': 'output logged requests'},
        ),
        migrations.AddField(
            model_name='celerytaskinvocationlog',
            name='release',
            field=models.CharField(blank=True, db_index=True, max_length=255, null=True, verbose_name='release'),
        ),
        migrations.AddField(
            model_name='celerytaskrunlog',
            name='release',
            field=models.CharField(blank=True, db_index=True, max_length=255, null=True, verbose_name='release'),
        ),
        migrations.AddField(
            model_name='celerytaskrunlog',
            name='waiting_time',
            field=models.FloatField(blank=True, null=True, verbose_name='waiting time'),
        ),
        migrations.AddField(
            model_name='commandlog',
            name='release',
            field=models.CharField(blank=True, db_index=True, max_length=255, null=True, verbose_name='release'),
        ),
        migrations.AddField(
            model_name='inputrequestlog',
            name='release',
            field=models.CharField(blank=True, db_index=True, max_length=255, null=True, verbose_name='release'),
        ),
        migrations.AddField(
            model_name='outputrequestlog',
            name='release',
            field=models.CharField(blank=True, db_index=True, max_length=255, null=True, verbose_name='release'),
        ),
    ]
